@@ -12,9 +12,8 @@ from cognite.airworkflow.util import cdf, env, functions, github
 
 def handle_asset_hierarchy():
     _, project_to_config = get_master_config()
-    assert len(sys.argv) < 3, "Expected not more than two arguments"
 
-    if len(sys.argv) == 2:
+    if len(sys.argv) >= 2:
         airInfra = sys.argv[2] == "True"
     else:
         airInfra = False
@@ -93,8 +92,6 @@ def handle_check_deployment():
 
 
 if __name__ == "__main__":
-    assert len(sys.argv) > 0, "Expected at least one argument."
-
     if sys.argv[1] == "model":
         handle_asset_hierarchy()
     elif sys.argv[1] == "function":
