@@ -1,10 +1,10 @@
-import os
+# import os
 from pathlib import Path
-from typing import Dict, List, Set
+from typing import Dict, Set
 
 from ruamel.yaml import YAML
 
-import cognite.airworkflow.util.file as file
+# import cognite.airworkflow.util.file as file
 from cognite.airworkflow.util import env
 
 
@@ -21,16 +21,10 @@ IGNORE_MODELS_PATH = ROOT_DIR / ".ignore_models"
 
 # Paths within a functions folder
 FUNCTION_REL_PATH = Path("function")
+REPOCONFIG_PATH = Path("repoconfig.yaml")
 FUNCTION_REL_CONFIG_PATH = FUNCTION_REL_PATH / "config.yaml"
 
 
 def project_name_finder() -> Set:
-    ignore_models = file.read_file_to_list(IGNORE_MODELS_PATH)
-
-    directory_contents = os.listdir(FUNCTIONS_PATH)
-    directory_paths: List = list(
-        filter(lambda x: x not in ignore_models, directory_contents),
-    )
-    function_paths: List = [x for x in directory_paths if os.path.isfile(FUNCTIONS_PATH / x / FUNCTION_REL_CONFIG_PATH)]
-
-    return set(function_paths)
+    repo_config = load_yaml(REPOCONFIG_PATH)["Projectproperties"].keys()
+    return set(repo_config)
